@@ -1,6 +1,7 @@
 """Core class for the Daymet functions."""
 import functools
 import warnings
+from datetime import datetime
 from typing import Dict, Iterable, List, Optional, Tuple, TypeVar, Union
 
 import numpy as np
@@ -9,7 +10,7 @@ import shapely.geometry as sgeom
 import xarray as xr
 from pydantic import BaseModel, validator
 
-from .exceptions import InvalidInputRange, InvalidInputType, InvalidInputValue
+from .exceptions import InputRangeError, InputTypeError, InputValueError
 
 try:
     from numba import njit, prange
@@ -35,6 +36,9 @@ DF = TypeVar("DF", pd.DataFrame, xr.Dataset)
 DEF_CRS = "epsg:4326"
 DATE_FMT = "%Y-%m-%d"
 
+# Default snow params from https://doi.org/10.5194/gmd-11-1077-2018
+T_RAIN = 2.5  # degC
+T_SNOW = 0.6  # degC
 
 __all__ = ["Daymet"]
 
@@ -82,20 +86,22 @@ class DaymetBase(BaseModel):
     region: str = "na"
 
     @validator("pet")
+    @classmethod
     def _pet(cls, v: Optional[str]) -> Optional[str]:
         valid_methods = ["penman_monteith", "hargreaves_samani", "priestley_taylor", None]
         if v not in valid_methods:
-            raise InvalidInputValue("pet", valid_methods)
+            raise InputValueError("pet", valid_methods)
         return v
 
     @validator("variables")
+    @classmethod
     def _variables(cls, v: List[str], values: Dict[str, str]) -> List[str]:
         valid_variables = ["dayl", "prcp", "srad", "swe", "tmax", "tmin", "vp"]
         if "all" in v:
             return valid_variables
 
         if not set(v).issubset(set(valid_variables)):
-            raise InvalidInputValue("variables", valid_variables)
+            raise InputValueError("variables", valid_variables)
 
         if values["pet"] is not None:
             v = list(set(v).union({"tmin", "tmax", "srad", "dayl"}))
@@ -105,27 +111,29 @@ class DaymetBase(BaseModel):
         return v
 
     @validator("time_scale")
+    @classmethod
     def _timescales(cls, v: str, values: Dict[str, str]) -> str:
         valid_timescales = ["daily", "monthly", "annual"]
         if v not in valid_timescales:
-            raise InvalidInputValue("time_scale", valid_timescales)
+            raise InputValueError("time_scale", valid_timescales)
 
         if values["pet"] is not None and v != "daily":
             msg = "PET can only be computed at daily scale i.e., time_scale must be daily."
-            raise InvalidInputRange(msg)
+            raise InputRangeError(msg)
         return v
 
     @validator("region")
+    @classmethod
     def _regions(cls, v: str) -> str:
         valid_regions = ["na", "hi", "pr"]
         if v not in valid_regions:
-            raise InvalidInputValue("region", valid_regions)
+            raise InputValueError("region", valid_regions)
         return v
 
 
 @ngjit("f8[::1](f8[::1], f8[::1], f8, f8)")  # type: ignore
 def _separate_snow(
-    prcp: np.ndarray, tmin: np.ndarray, t_rain: float = 2.5, t_snow: float = 0.0  # type: ignore
+    prcp: np.ndarray, tmin: np.ndarray, t_rain: float = T_RAIN, t_snow: float = T_SNOW  # type: ignore
 ) -> np.ndarray:  # type: ignore
     """Separate snow in precipitation."""
     t_rng = t_rain - t_snow
@@ -212,7 +220,7 @@ class Daymet:
             self.valid_start = pd.to_datetime("1950-01-01")
         else:
             self.valid_start = pd.to_datetime("1980-01-01")
-        self.valid_end = pd.to_datetime("2020-12-31")
+        self.valid_end = pd.to_datetime(f"{datetime.now().year - 1}-12-31")
         self._invalid_yr = (
             "Daymet database ranges from " + f"{self.valid_start.year} to {self.valid_end.year}."
         )
@@ -257,19 +265,17 @@ class Daymet:
     def check_dates(dates: Union[Tuple[str, str], Union[int, List[int]]]) -> None:
         """Check if input dates are in correct format and valid."""
         if not isinstance(dates, (tuple, list, int)):
-            raise InvalidInputType(
+            raise InputTypeError(
                 "dates", "tuple, list, or int", "(start, end), year, or [years, ...]"
             )
 
         if isinstance(dates, tuple) and len(dates) != 2:
-            raise InvalidInputType(
-                "dates", "Start and end should be passed as a tuple of length 2."
-            )
+            raise InputTypeError("dates", "Start and end should be passed as a tuple of length 2.")
 
     def dates_todict(self, dates: Tuple[str, str]) -> Dict[str, str]:
         """Set dates by start and end dates as a tuple, (start, end)."""
         if not isinstance(dates, tuple) or len(dates) != 2:
-            raise InvalidInputType("dates", "tuple", "(start, end)")
+            raise InputTypeError("dates", "tuple", "(start, end)")
 
         start = pd.to_datetime(dates[0])
         end = pd.to_datetime(dates[1])
@@ -277,8 +283,12 @@ class Daymet:
             start = start.replace(day=14)
             end = end.replace(day=17)
 
+        if self.time_scale == "annual":
+            start = start.replace(day=6)
+            end = end.replace(day=8)
+
         if start < self.valid_start or end > self.valid_end:
-            raise InvalidInputRange(self._invalid_yr)
+            raise InputRangeError(self._invalid_yr)
 
         return {
             "start": start.strftime(DATE_FMT),
@@ -290,7 +300,7 @@ class Daymet:
         years = [years] if isinstance(years, int) else years
 
         if min(years) < self.valid_start.year or max(years) > self.valid_end.year:
-            raise InvalidInputRange(self._invalid_yr)
+            raise InputRangeError(self._invalid_yr)
 
         return {"years": ",".join(str(y) for y in years)}
 
@@ -390,7 +400,7 @@ class Daymet:
         clm["snow"].attrs["long_name"] = "daily snowfall"
         return clm
 
-    def separate_snow(self, clm: DF, t_rain: float = 2.5, t_snow: float = 0.0) -> DF:
+    def separate_snow(self, clm: DF, t_rain: float = T_RAIN, t_snow: float = T_SNOW) -> DF:
         """Separate snow based on :footcite:t:`Martinez_2010`.
 
         Parameters
@@ -400,7 +410,7 @@ class Daymet:
         t_rain : float, optional
             Threshold for temperature for considering rain, defaults to 2.5 degrees C.
         t_snow : float, optional
-            Threshold for temperature for considering snow, defaults to 0.0 degrees C.
+            Threshold for temperature for considering snow, defaults to 0.6 degrees C.
 
         Returns
         -------
@@ -416,7 +426,7 @@ class Daymet:
             warnings.warn("Numba not installed. Using slow pure python version.", UserWarning)
 
         if not isinstance(clm, (pd.DataFrame, xr.Dataset)):
-            raise InvalidInputType("clm", "pandas.DataFrame or xarray.Dataset")
+            raise InputTypeError("clm", "pandas.DataFrame or xarray.Dataset")
 
         if isinstance(clm, xr.Dataset):
             return self._snow_gridded(clm, t_rain, t_snow)
