@@ -1,5 +1,5 @@
 """Core class for the Daymet functions."""
-from typing import Dict, Iterable, List, Optional, Tuple, TypeVar, Union
+from typing import Dict, Hashable, Iterable, KeysView, Optional, Tuple, TypeVar, Union
 
 import numpy as np
 import pandas as pd
@@ -8,7 +8,7 @@ import pygeoogc as ogc
 import pyproj
 import xarray as xr
 
-from .exceptions import InvalidInputType, InvalidInputValue, MissingItems
+from .exceptions import InputTypeError, InputValueError, MissingItemError
 
 DEF_CRS = "epsg:4326"
 DF = TypeVar("DF", pd.DataFrame, xr.Dataset)
@@ -156,7 +156,7 @@ def net_radiation(
         * (0.34 - 0.14 * np.sqrt(e_a))
         * ((1.35 * r_surf / rad_s) - 0.35)
     )
-    return rad_ns - rad_nl  # type: ignore
+    return rad_ns - rad_nl
 
 
 def psychrometric_constant(elevation: Union[float, xr.DataArray], lmbda: DS) -> DS:
@@ -200,8 +200,8 @@ def vapour_slope(tmean_c: DS) -> DS:
     ----------
     .. footbibliography::
     """  # noqa: DAR203
-    return (  # type: ignore
-        4098
+    return (
+        4098  # type: ignore
         * (
             0.6108
             * np.exp(
@@ -212,7 +212,7 @@ def vapour_slope(tmean_c: DS) -> DS:
     )
 
 
-def check_requirements(reqs: Iterable[str], cols: List[str]) -> None:
+def check_requirements(reqs: Iterable[str], cols: Union[KeysView[Hashable], pd.Index]) -> None:
     """Check for all the required data.
 
     Parameters
@@ -223,11 +223,11 @@ def check_requirements(reqs: Iterable[str], cols: List[str]) -> None:
         A list of variable names (str)
     """
     if not isinstance(reqs, Iterable):
-        raise InvalidInputType("reqs", "iterable")
+        raise InputTypeError("reqs", "iterable")
 
     missing = [r for r in reqs if r not in cols]
     if missing:
-        raise MissingItems(missing)
+        raise MissingItemError(missing)
 
 
 class PETCoords:
@@ -274,7 +274,7 @@ class PETCoords:
         self.u2 = "u2 (m/s)"
 
         self.tmean = 0.5 * (self.clm[self.tmax] + self.clm[self.tmin])
-        self.clm_vars = list(self.clm.columns)
+        self.clm_vars = self.clm.columns
         self.req_vars = {
             "penman_monteith": [self.tmin, self.tmax, self.srad, self.dayl],
             "priestley_taylor": [self.tmin, self.tmax, self.srad, self.dayl],
@@ -434,34 +434,26 @@ class PETGridded:
         clm: xr.Dataset,
         params: Optional[Dict[str, float]] = None,
     ) -> None:
-        self.clm = clm
+        self.clm = clm.copy()
         self.params = params if isinstance(params, dict) else {"soil_heat": 0.0}
         self.res = 1.0e3
-        self.crs = " ".join(
-            [
-                "+proj=lcc",
-                "+lat_1=25",
-                "+lat_2=60",
-                "+lat_0=42.5",
-                "+lon_0=-100",
-                "+x_0=0",
-                "+y_0=0",
-                "+ellps=WGS84",
-                "+units=km",
-                "+no_defs",
-            ]
-        )
+        self.crs = clm.rio.crs
 
         self.clm["tmean"] = 0.5 * (self.clm["tmax"] + self.clm["tmin"])
-        self.clm["elevation"] = py3dep.elevation_bygrid(
+        dem = py3dep.elevation_bygrid(
             self.clm.x.values, self.clm.y.values, self.crs, self.res
-        ).chunk({"x": clm.chunksizes["x"], "y": clm.chunksizes["y"]})
+        ).where(~self.clm.tmin.isel(time=0).isnull())
+
+        if "x" in self.clm.chunksizes and "y" in self.clm.chunksizes:
+            dem = dem.chunk({"x": self.clm.chunksizes["x"], "y": self.clm.chunksizes["y"]})
+
+        self.clm["elevation"] = dem
 
         # recommended when no data is not available to estimate soil heat flux
         if "soil_heat" not in self.params:
             self.params["soil_heat"] = 0.0
 
-        self.clm_vars = list(self.clm.keys())
+        self.clm_vars = self.clm.keys()
         self.req_vars = {
             "penman_monteith": ["tmin", "tmax", "lat", "srad", "dayl"],
             "priestley_taylor": ["tmin", "tmax", "lat", "srad", "dayl"],
@@ -477,7 +469,7 @@ class PETGridded:
         clm : xarray.DataArray
             The dataset to which the new attributes are added.
         """
-        dtype = clm[next(iter(clm.keys()))].dtype
+        dtype = clm.tmin.dtype
         clm["elevation"].attrs = {"units": "m", "long_name": "elevation"}
         clm["elevation"] = clm["elevation"].astype(dtype)
         clm["pet"].attrs = {"units": "mm/day", "long_name": "daily potential evapotranspiration"}
@@ -695,15 +687,15 @@ def potential_et(
     """  # noqa: DAR203
     valid_methods = ["penman_monteith", "hargreaves_samani", "priestley_taylor"]
     if method not in valid_methods:
-        raise InvalidInputValue("method", valid_methods)
+        raise InputValueError("method", valid_methods)
 
     if not isinstance(clm, (pd.DataFrame, xr.Dataset)):
-        raise InvalidInputType("clm", "pd.DataFrame or xr.Dataset")
+        raise InputTypeError("clm", "pd.DataFrame or xr.Dataset")
 
     pet: Union[PETCoords, PETGridded]
     if isinstance(clm, pd.DataFrame):
         if coords is None:
-            raise MissingItems(["coords"])
+            raise MissingItemError(["coords"])
         crs = ogc.utils.validate_crs(crs)
         pet = PETCoords(clm, coords, crs, params)
     else:
