@@ -15,8 +15,8 @@ from pygeoogc import ServiceError, ServiceURL
 from pygeoogc import utils as ogcutils
 from shapely.geometry import MultiPolygon, Point, Polygon
 
-from .core import Daymet
-from .exceptions import InvalidInputRange, InvalidInputType
+from .core import T_RAIN, T_SNOW, Daymet
+from .exceptions import InputRangeError, InputTypeError
 from .pet import potential_et
 
 DEF_CRS = "epsg:4326"
@@ -158,7 +158,8 @@ def get_bycoords(
         These parameters are only used if ``snow`` is ``True``. Two parameters are required:
         ``t_rain`` (deg C) which is the threshold for temperature for considering rain and
         ``t_snow`` (deg C) which is the threshold for temperature for considering snow.
-        The default values are ``{'t_rain': 2.5, 't_snow': 0}``.
+        The default values are ``{'t_rain': 2.5, 't_snow': 0.6}`` that are adopted from
+        https://doi.org/10.5194/gmd-11-1077-2018.
     ssl : bool or SSLContext, optional
         SSLContext to use for the connection, defaults to None. Set to False to disable
         SSL certification verification.
@@ -196,12 +197,12 @@ def get_bycoords(
         dates_itr = daymet.years_tolist(dates)
 
     if not (isinstance(coords, tuple) and len(coords) == 2):
-        raise InvalidInputType("coords", "tuple", "(lon, lat)")
+        raise InputTypeError("coords", "tuple", "(lon, lat)")
 
     coords = ogcutils.match_crs([coords], crs, DEF_CRS)[0]
 
     if not Point(*coords).within(daymet.region_bbox[region]):
-        raise InvalidInputRange(daymet.invalid_bbox_msg)
+        raise InputRangeError(daymet.invalid_bbox_msg)
 
     url_kwds = _coord_urls(
         daymet.time_codes[time_scale], coords, daymet.region, daymet.variables, dates_itr
@@ -230,7 +231,7 @@ def get_bycoords(
         clm = potential_et(clm, coords, method=pet, params=pet_params)
 
     if snow:
-        params = {"t_rain": 2.5, "t_snow": 0} if snow_params is None else snow_params
+        params = {"t_rain": T_RAIN, "t_snow": T_SNOW} if snow_params is None else snow_params
         clm = daymet.separate_snow(clm, **params)
     return clm
 
@@ -356,7 +357,8 @@ def get_bygeom(
         These parameters are only used if ``snow`` is ``True``. Two parameters are required:
         ``t_rain`` (deg C) which is the threshold for temperature for considering rain and
         ``t_snow`` (deg C) which is the threshold for temperature for considering snow.
-        The default values are ``{'t_rain': 2.5, 't_snow': 0}``.
+        The default values are ``{'t_rain': 2.5, 't_snow': 0.6}`` that are adopted from
+        https://doi.org/10.5194/gmd-11-1077-2018.
     ssl : bool or SSLContext, optional
         SSLContext to use for the connection, defaults to None. Set to False to disable
         SSL certification verification.
@@ -393,7 +395,7 @@ def get_bygeom(
     _geometry = geoutils.geo2polygon(geometry, crs, DEF_CRS)
 
     if not _geometry.intersects(daymet.region_bbox[region]):
-        raise InvalidInputRange(daymet.invalid_bbox_msg)
+        raise InputRangeError(daymet.invalid_bbox_msg)
 
     urls, kwds = zip(
         *_gridded_urls(
@@ -406,8 +408,8 @@ def get_bygeom(
     )
 
     try:
-        clm: xr.Dataset = xr.open_mfdataset(  # type: ignore
-            (
+        clm: xr.Dataset = xr.open_mfdataset(
+            (  # type: ignore
                 io.BytesIO(r)
                 for r in ar.retrieve_binary(urls, request_kwds=kwds, max_workers=MAX_CONN, ssl=ssl)
             ),
@@ -450,6 +452,6 @@ def get_bygeom(
         clm = potential_et(clm, method=pet, params=pet_params)
 
     if snow:
-        params = {"t_rain": 2.5, "t_snow": 0} if snow_params is None else snow_params
+        params = {"t_rain": T_RAIN, "t_snow": T_SNOW} if snow_params is None else snow_params
         clm = daymet.separate_snow(clm, **params)
     return clm
