@@ -12,6 +12,20 @@ from shapely.geometry import Polygon
 import pydaymet as daymet
 from pydaymet.cli import cli
 
+try:
+    import typeguard  # noqa: F401
+
+    hastypeguard = True
+except ImportError:
+    hastypeguard = False
+
+try:
+    import numba  # noqa: F401
+
+    hasnumba = True
+except ImportError:
+    hasnumba = False
+
 GEOM = Polygon(
     [[-69.77, 45.07], [-69.31, 45.07], [-69.31, 45.45], [-69.77, 45.45], [-69.77, 45.07]]
 )
@@ -34,6 +48,7 @@ class TestByCoords:
         clm = daymet.get_bycoords(COORDS, DATES, crs=ALT_CRS, pet=method, ssl=False)
         assert abs(clm["pet (mm/day)"].mean() - expected) < SMALL
 
+    @pytest.mark.skipif(hastypeguard and hasnumba, reason="typeguard doesn't work with numba")
     def test_snow(self):
         clm = daymet.get_bycoords(COORDS, DATES, snow=True, crs=ALT_CRS, ssl=False)
         assert abs(clm["snow (mm/day)"].mean()) < SMALL
@@ -62,27 +77,28 @@ class TestByGeom:
     )
     def test_pet(self, method, expected):
         clm = daymet.get_bygeom(GEOM, DAY, pet=method, ssl=False)
-        assert abs(clm.pet.mean().values - expected) < SMALL
+        assert abs(clm.pet.mean().compute().item() - expected) < SMALL
 
+    @pytest.mark.skipif(hastypeguard and hasnumba, reason="typeguard doesn't work with numba")
     def test_snow(self):
-        clm = daymet.get_bygeom(GEOM, DAY, snow=True, ssl=False)
-        assert abs(clm.snow.mean().values - 3.4999) < SMALL
+        clm = daymet.get_bygeom(GEOM, DAY, snow=True, snow_params={"t_snow": 0.5})
+        assert abs(clm.snow.mean().compute().item() - 3.4999) < SMALL
 
     def test_bounds(self):
         clm = daymet.get_bygeom(GEOM.bounds, DAY, ssl=False)
-        assert abs(clm.prcp.mean().values - 3.4999) < SMALL
+        assert abs(clm.prcp.mean().compute().item() - 3.4999) < SMALL
 
     def test_daily(self):
         clm = daymet.get_bygeom(GEOM, DAY, variables=VAR, ssl=False)
-        assert abs(clm.tmin.mean().values - (-9.421)) < SMALL
+        assert abs(clm.tmin.mean().compute().item() - (-9.421)) < SMALL
 
     def test_monthly(self):
         clm = daymet.get_bygeom(GEOM, YEAR, variables=VAR, time_scale="monthly", ssl=False)
-        assert abs(clm.tmin.mean().values - 1.311) < SMALL
+        assert abs(clm.tmin.mean().compute().item() - 1.311) < SMALL
 
     def test_annual(self):
         clm = daymet.get_bygeom(GEOM, YEAR, variables=VAR, time_scale="annual", ssl=False)
-        assert abs(clm.tmin.mean().values - 1.361) < SMALL
+        assert abs(clm.tmin.mean().compute().item() - 1.361) < SMALL
 
     def test_region(self):
         hi_ext = (-160.3055, 17.9539, -154.7715, 23.5186)
@@ -95,8 +111,8 @@ class TestByGeom:
         )
 
         assert (
-            abs(hi.prcp.mean().values - 1035.233) < SMALL
-            and abs(pr.tmin.mean().values - 21.441) < SMALL
+            abs(hi.prcp.mean().compute().item() - 1035.233) < SMALL
+            and abs(pr.tmin.mean().compute().item() - 21.441) < SMALL
         )
 
 
